@@ -18,7 +18,7 @@ require 'ctioga2/data/indexed-dtable'
 
 module CTioga2
 
-  Version::register_svn_info('$Revision: 304 $', '$Date: 2012-01-03 15:06:33 +0100 (Tue, 03 Jan 2012) $')
+  Version::register_svn_info('$Revision: 406 $', '$Date: 2013-08-22 21:23:44 +0200 (Thu, 22 Aug 2013) $')
 
 
   # \todo now, port the backend infrastructure...
@@ -393,18 +393,8 @@ module CTioga2
       #
       # @todo add algorithm
       def make_contour(level)
-        dtable = indexed_table
-        x,y,gaps = *dtable.make_contour(level)
-
-        # We remove any gap corresponding to the element size,
-        # meaningless.
-        gaps -= [x.size]
-        n = 0.0/0.0
-        gaps.sort.reverse.each do |i|
-          x.insert(i,n)
-          y.insert(i,n)
-        end
-        return Dobjects::Function.new(x,y)
+        table = indexed_table
+        return table.make_contour(level, {'ret' => 'func'} )
       end
 
       # Smooths the data using a naive gaussian-like convolution (but
