@@ -22,7 +22,7 @@ require 'shellwords'
 # This module contains all the classes used by ctioga
 module CTioga2
 
-  Version::register_svn_info('$Revision: 370 $', '$Date: 2012-12-28 17:40:18 +0100 (Fri, 28 Dec 2012) $')
+  Version::register_svn_info('$Revision: 391 $', '$Date: 2013-03-14 11:04:36 +0100 (Thu, 14 Mar 2013) $')
 
   module Graphics
 
@@ -231,8 +231,8 @@ EOD
                          [ 'point', 'point' ], 
                          Styles::ArrowStyle,
                          'arrow') do |t, tail, head, style, options|
-          style.draw_arrow(t, *tail.to_figure_xy(t),
-                           *head.to_figure_xy(t))
+          style.draw_arrow(t, *( tail.to_figure_xy(t) + 
+                           head.to_figure_xy(t) ))
         end
 
         styled_primitive("line", "line", 
@@ -240,8 +240,8 @@ EOD
                          Styles::StrokeStyle,
                          'line'
                   ) do |t, tail, head, style, options|
-          style.draw_line(t, *(tail.to_figure_xy(t)),
-                          *(head.to_figure_xy(t)))
+          style.draw_line(t, *( tail.to_figure_xy(t) + 
+                          head.to_figure_xy(t) ))
         end
 
         # Here, we need to add deprecated options for backward
