@@ -18,7 +18,7 @@ require 'ctioga2/graphics/coordinates'
 
 module CTioga2
 
-  Version::register_svn_info('$Revision: 311 $', '$Date: 2012-04-16 22:51:59 +0200 (Mon, 16 Apr 2012) $')
+  Version::register_svn_info('$Revision: 412 $', '$Date: 2013-08-22 23:04:59 +0200 (Thu, 22 Aug 2013) $')
 
   module Graphics
 
@@ -73,13 +73,17 @@ module CTioga2
           CurveStyleFactory::PlotCommandOptions.key?(k)
         }
 
-
-        return send(@current_curves, plot, dataset, options)
+        curve = send(@current_curves, plot, dataset, options)
+        curve.curve_style.target = curve
+        return curve
       end
 
       private
       
       ## \name Available kinds of curves
+      ##
+      ## @todo All these are completely identical, there probably
+      ## isn't need for separate code ?
       # 
       # @{
       # 
@@ -98,11 +102,11 @@ module CTioga2
       def xy_parametric(plot, dataset, options = {})
         legend = @legend_provider.dataset_legend(dataset)
         style = @style_factory.next(options)
-        style.legend = false
         style.legend ||= legend # The legend specified as option to
                                 # the --plot command has precedence
                                 # over the one specified by --legend.
         curve = Graphics::Elements::Parametric2D.new(dataset, style)
+        style
         return curve
       end
 
@@ -110,14 +114,26 @@ module CTioga2
       def xyz_map(plot, dataset, options = {})
         legend = @legend_provider.dataset_legend(dataset)
         style = @style_factory.next(options)
-        style.legend = false
         style.legend ||= legend # The legend specified as option to
                                 # the --plot command has precedence
                                 # over the one specified by --legend.
+        style.legend = false    # No legend for XYZ maps
         curve = Graphics::Elements::XYZMap.new(dataset, style)
         return curve
       end
 
+      # XYZ maps
+      def xyz_contour(plot, dataset, options = {})
+        legend = @legend_provider.dataset_legend(dataset)
+        style = @style_factory.next(options)
+        style.legend ||= legend # The legend specified as option to
+                                # the --plot command has precedence
+                                # over the one specified by --legend.
+        style.legend = false    # No legend for XYZ maps
+        curve = Graphics::Elements::XYZContour.new(dataset, style)
+        return curve
+      end
+
 
       ## @}
       
@@ -141,6 +157,16 @@ module CTioga2
 Switch to XY parametric plots, that is standard XY plots whose appearance
 (such as color, marker color, and, potentially, marker kinds and more)
 are governed by one (or more ?) Z values.
+EOH
+
+    ContourPlotCommand = 
+      Cmd.new("contour",nil,"--contour") do |plotmaker|
+      plotmaker.curve_generator.current_curves = :xyz_contour
+    end
+    
+    ContourPlotCommand.describe('select contour plots', 
+                                     <<EOH, PlotTypesGroup)
+...
 EOH
 
     XYPlotCommand = 
