@@ -17,7 +17,7 @@ require 'ctioga2/log'
 # This module contains all the classes used by ctioga
 module CTioga2
 
-  Version::register_svn_info('$Revision: 357 $', '$Date: 2012-12-26 00:49:11 +0100 (Wed, 26 Dec 2012) $')
+  Version::register_svn_info('$Revision: 435 $', '$Date: 2013-08-26 22:03:19 +0200 (Mon, 26 Aug 2013) $')
 
   module Graphics
 
@@ -72,6 +72,8 @@ module CTioga2
         typed_attribute :minor_tick_length, 'float'
         typed_attribute :minor_tick_width, 'float'
 
+        typed_attribute :ticks_side, 'ticks-side'
+
 
         # Creates a new AxisStyle object at the given location with
         # the given style.
@@ -80,8 +82,10 @@ module CTioga2
           @decoration = decoration
 
           @tick_label_style = FullTextStyle.new
+          @tick_label_style.scale = Types::Dimension.new(:dy, 0.8)
           @axis_label = TextLabel.new(label)
           @log = false
+          @ticks_side = {}
         end
 
         # Draws the axis within the current plot. Boundaries are the
@@ -96,7 +100,7 @@ module CTioga2
         def draw_axis(t)
           spec = get_axis_specification(t)
           # Add tick label style:
-          spec.merge!(@tick_label_style.to_hash)
+          spec.merge!(@tick_label_style.hash_for_tioga(t))
 
           # Direct copy of attributes 
           for key in %w(stroke_color major_tick_length major_tick_width
@@ -106,6 +110,8 @@ minor_tick_length minor_tick_width)
               spec[key] = val
             end
           end
+
+          spec.update(@ticks_side)
           t.show_axis(spec)
           @axis_label.loc = @location
           default = vertical? ? 'ylabel' : 'xlabel'
@@ -213,8 +219,8 @@ minor_tick_length minor_tick_width)
         def get_ticks_parameters(t)
           i = t.axis_information({'location' => @location.tioga_location})
           retval = []
-          retval << (@tick_label_style.shift || i['shift'])
-          retval << (@tick_label_style.scale || i['scale'])
+          retval << (@tick_label_style.shift_dy(t) || i['shift'])
+          retval << (@tick_label_style.scale_dy(t) || i['scale'])
 
           retval[0] += 1
           return retval
