@@ -25,7 +25,7 @@ require 'ctioga2/graphics/types/grid'
 # This module contains all the classes used by ctioga
 module CTioga2
 
-  Version::register_svn_info('$Revision: 344 $', '$Date: 2012-12-23 22:45:22 +0100 (Sun, 23 Dec 2012) $')
+  Version::register_svn_info('$Revision: 376 $', '$Date: 2013-01-23 22:52:47 +0100 (Wed, 23 Jan 2013) $')
 
   module Graphics
 
@@ -216,6 +216,25 @@ tick labels. Possible values:
  * @full@: major ticks and labels + minor ticks
 EOD
 
+    TicksSideRE = {
+      /i(nside)?/i =>  {'ticks_inside' => true,
+        'ticks_outside' => false},
+      /o(utside)?/i => {'ticks_outside' => true,
+        'ticks_inside' => false},
+      /b(oth)?/i => {'ticks_outside' => true,
+        'ticks_inside' => true}
+    }
+
+    TicksSideType = 
+      CmdType.new('ticks-side', {:type => :re_list,
+                    :list => TicksSideRE}, <<EOD)
+On what side of an axis line are the ticks positioned:
+ * @inside@: on the inside
+ * @outside@: on the outside
+ * @both@: on both the inside and the outside
+EOD
+
+
     # Dimensions
 
     DimensionType = 
