@@ -16,7 +16,7 @@ require 'ctioga2/log'
 
 module CTioga2
 
-  Version::register_svn_info('$Revision: 328 $', '$Date: 2012-11-28 15:11:49 +0100 (Wed, 28 Nov 2012) $')
+  Version::register_svn_info('$Revision: 433 $', '$Date: 2013-08-26 22:03:14 +0200 (Mon, 26 Aug 2013) $')
 
   module Graphics
 
@@ -77,6 +77,12 @@ module CTioga2
           end
         end
 
+        # Return the value of the dimension in units of text height
+        def to_dy(t)
+          fig = to_figure(t, :y)
+          return fig/t.default_text_height_dy
+        end
+
         # Converts the Dimension to the *frame* coordinates of the
         # *current* frame in _t_.
         def to_frame(t, orientation = nil)
