@@ -155,7 +155,7 @@ require 'ctioga2/postprocess'
 # displays of rate constants vs potentials)
 module CTioga2
 
-  Version::register_svn_info('$Revision: 314 $', '$Date: 2012-08-10 11:59:35 +0200 (Fri, 10 Aug 2012) $')
+  Version::register_svn_info('$Revision: 431 $', '$Date: 2013-08-23 17:58:47 +0200 (Fri, 23 Aug 2013) $')
 
   # This class is the core of ctioga. It parses the command-line arguments,
   # reads all necessary files and plots graphs. Most of its functionality
@@ -354,6 +354,17 @@ module CTioga2
       end
       t.make_preview_pdf(t.figure_index(figname))
 
+      # We look for latex errors
+      if t.respond_to? :pdflatex_errors
+        errs = t.pdflatex_errors
+        if errs.size > 0
+          error { "pdflatex returned with #{errs.size} error lines"}
+          for l in errs
+            warn { "pdflatex error: #{l.chomp}" }
+          end
+        end
+      end
+
       file = t.save_dir ? File::join(t.save_dir, figname + ".pdf") : 
         figname + ".pdf"
 
