@@ -34,7 +34,7 @@ module CTioga2
     # arguments and have the Date and Revision svn:keyword:. Use this
     # way:
     #
-    #  Version::register_svn_info('$Revision: 354 $', '$Date: 2012-12-25 23:39:59 +0100 (Tue, 25 Dec 2012) $')
+    #  Version::register_svn_info('$Revision: 424 $', '$Date: 2013-08-23 10:16:34 +0200 (Fri, 23 Aug 2013) $')
     #
     # To set the correct properties, the following command-line can be
     # used:
@@ -74,7 +74,7 @@ module CTioga2
     }
 
     # The position of the URL, used for getting the version
-    SVN_URL = '$HeadURL: svn+ssh://rubyforge.org/var/svn/ctioga2/releases/ctioga2-0.4/lib/ctioga2/utils.rb $'
+    SVN_URL = '$HeadURL: svn+ssh://rubyforge.org/var/svn/ctioga2/releases/ctioga2-0.5/lib/ctioga2/utils.rb $'
     
     # The version of ctioga2
     CTIOGA_VERSION = if SVN_URL =~ /releases\/ctioga2-([^\/]+)/
@@ -83,7 +83,7 @@ module CTioga2
                        "SVN version"
                      end
 
-    register_svn_info('$Revision: 354 $', '$Date: 2012-12-25 23:39:59 +0100 (Tue, 25 Dec 2012) $')
+    register_svn_info('$Revision: 424 $', '$Date: 2013-08-23 10:16:34 +0200 (Fri, 23 Aug 2013) $')
 
   end
 
@@ -161,6 +161,30 @@ module CTioga2
       end
       return formula
     end
+
+    NaturalSubdivisions = [1.0, 2.0, 5.0, 10.0]
+
+    # Returns the closest element of the correct power of ten of
+    # NaturalSubdivisions above or below the given number
+    def self.closest_subdivision(x, below = true)
+      fact = 10**(Math.log10(x).floor)
+
+      normed_x = x/fact
+      (NaturalSubdivisions.size()-1).times do |i|
+        if normed_x == NaturalSubdivisions[i]
+          return x
+        end
+        if (normed_x > NaturalSubdivisions[i]) && 
+            (normed_x < NaturalSubdivisions[i+1])
+          if below
+            return NaturalSubdivisions[i]*fact
+          else
+            return NaturalSubdivisions[i+1]*fact
+          end
+        end
+      end
+      raise "Should not reach this !"
+    end
     
 
   end
